summaryrefslogtreecommitdiff
path: root/indra/llmessage/llcoproceduremanager.cpp
diff options
context:
space:
mode:
authorRider Linden <rider@lindenlab.com>2015-09-18 11:39:22 -0700
committerRider Linden <rider@lindenlab.com>2015-09-18 11:39:22 -0700
commit75c6549fde060e974c90636685962ee373f94202 (patch)
tree0c041c248d045b83ef10b561bf26dc64e3716def /indra/llmessage/llcoproceduremanager.cpp
parent2108b3e540406daf08d2845ac395ad4bb1633b35 (diff)
Set consistent terminology for yield/wait -> suspend for coroutines.
Diffstat (limited to 'indra/llmessage/llcoproceduremanager.cpp')
-rw-r--r--indra/llmessage/llcoproceduremanager.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/indra/llmessage/llcoproceduremanager.cpp b/indra/llmessage/llcoproceduremanager.cpp
index 10519d990e..f0fe1ab01b 100644
--- a/indra/llmessage/llcoproceduremanager.cpp
+++ b/indra/llmessage/llcoproceduremanager.cpp
@@ -58,7 +58,7 @@ public:
LLUUID enqueueCoprocedure(const std::string &name, CoProcedure_t proc);
/// Cancel a coprocedure. If the coprocedure is already being actively executed
/// this method calls cancelYieldingOperation() on the associated HttpAdapter
/// If it has not yet been dequeued it is simply removed from the queue.
bool cancelCoprocedure(const LLUUID &id);
@@ -316,7 +316,7 @@ void LLCoprocedurePool::shutdown(bool hardShutdown)
}
if ((*it).second)
{
- (*it).second->cancelYieldingOperation();
+ (*it).second->cancelSuspendedOperation();
}
}
@@ -345,7 +345,7 @@ bool LLCoprocedurePool::cancelCoprocedure(const LLUUID &id)
if (itActive != mActiveCoprocs.end())
{
LL_INFOS() << "Found and canceling active coprocedure with id=" << id.asString() << " in pool \"" << mPoolName << "\"" << LL_ENDL;
- (*itActive).second->cancelYieldingOperation();
+ (*itActive).second->cancelSuspendedOperation();
mActiveCoprocs.erase(itActive);
return true;
}
@@ -371,7 +371,7 @@ void LLCoprocedurePool::coprocedureInvokerCoro(LLCoreHttpUtil::HttpCoroutineAdap
while (!mShutdown)
{
- llcoro::waitForEventOn(mWakeupTrigger);
+ llcoro::suspendUntilEventOn(mWakeupTrigger);
if (mShutdown)
break;
@@ -58,7 +58,7 @@ public:
LLUUID enqueueCoprocedure(const std::string &name, CoProcedure_t proc);
/// Cancel a coprocedure. If the coprocedure is already being actively executed
- /// this method calls cancelYieldingOperation() on the associated HttpAdapter
+ /// this method calls cancelSuspendedOperation() on the associated HttpAdapter
/// If it has not yet been dequeued it is simply removed from the queue.
bool cancelCoprocedure(const LLUUID &id);